@@ -1,3 +1,5 @@
+use utf8;
+use warnings;
 no warnings 'redefine';
 use vars qw($r);
 
@@ -63,7 +65,7 @@ sub showDir {
             href =>
               "javascript:requestURI('$m_hrSettings->{cgi}{serverName}$ENV{SCRIPT_NAME}?action=FileOpen&file=$esubfolder&sort=1&desc=$newstate','FileOpen','FileOpen');",
             class => "treeviewLink$m_hrSettings->{size}",
-            align => "left",
+            align => 'left',
            },
            'Name'
          )
@@ -144,7 +146,7 @@ sub showDir {
            'GID'
          )
           . (
-            $byColumn == 3
+            $byColumn eq 3
             ? (
                $state
                ? qq| <img src="/style/$m_sStyle/$m_hrSettings->{size}/mimetypes/up.png" border="0" alt="" title="up" width="16" height="16"/>|
