@@ -1,3 +1,6 @@
+use utf8;
+use warnings;
+no warnings 'redefine';
 sub reg {
     my $sUserRegName = param('username');
     $sUserRegName = ($sUserRegName =~ /^(\w{3,10})$/) ? $1 : translate('insertname');
