@@ -1,59 +1,59 @@
 $VAR1 = {
-          'version' => '0.95',
-          'defaultAction' => 'ShowDatabases',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'htmlright' => '2',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'floodtime' => 10,
           'tree' => {
-                      'navigation' => '/var/www/cgi-bin/config/tree.pl',
-                      'links' => '/var/www/cgi-bin/config/links.pl'
+                      'links' => '/var/www/cgi-bin/config/links.pl',
+                      'navigation' => '/var/www/cgi-bin/config/tree.pl'
+                    },
+          'files' => {
+                       'owner' => 'lze',
+                       'group' => 'lze',
+                       'chmod' => '0755'
+                     },
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'size' => '16',
+          'saveTranslate' => '0',
+          'defaultAction' => 'ShowDatabases',
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'language' => 'en',
+          'news' => {
+                      'captcha' => 3,
+                      'messages' => '5',
+                      'right' => 5
                     },
           'database' => {
                           'user' => 'root',
-                          'CurrentPass' => '',
+                          'name' => 'MySQLAdmin',
+                          'CurrentHost' => 'localhost',
+                          'CurrentUser' => 'root',
                           'CurrentDb' => 'MySQLAdmin',
                           'password' => '',
-                          'name' => 'MySQLAdmin',
-                          'CurrentUser' => 'root',
                           'host' => 'localhost',
-                          'CurrentHost' => 'localhost'
+                          'CurrentPass' => ''
                         },
-          'size' => '16',
-          'floodtime' => 10,
-          'htmlright' => '2',
-          'uploads' => {
-                         'path' => '/var/www/htdocs//download',
-                         'enabled' => 1,
-                         'chmod' => 438,
-                         'right' => 2,
-                         'maxlength' => '2100000000000000'
-                       },
-          'saveTranslate' => '0',
-          'mod' => 'n',
-          'language' => 'en',
           'cgi' => {
+                     'title' => 'MySQL::Admin',
+                     'DocumentRoot' => '/var/www/htdocs/',
                      'serverName' => 'http://localhost',
                      'expires' => '+1y',
-                     'DocumentRoot' => '/var/www/htdocs/',
-                     'style' => 'mysql',
                      'bin' => '/var/www/cgi-bin',
-                     'cookiePath' => '/',
-                     'title' => 'MySQL::Admin'
+                     'style' => 'mysql',
+                     'cookiePath' => '/'
                    },
+          'version' => '0.96',
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'uploads' => {
+                         'enabled' => 1,
+                         'chmod' => 438,
+                         'maxlength' => '2100000000000000',
+                         'path' => '/var/www/htdocs//download',
+                         'right' => 2
+                       },
+          'mod' => 'n',
           'admin' => {
                        'password' => 'testpass'
-                     },
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'news' => {
-                      'messages' => '5',
-                      'right' => 5,
-                      'captcha' => 3
-                    },
-          'files' => {
-                       'chmod' => '0755',
-                       'owner' => 'lze',
-                       'group' => 'lze'
-                     },
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
-          'session' => '/var/www/cgi-bin/config/session.pl'
+                     }
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
